==> senior_platform_authentication_ui-0.0.1.tar.gz: test/src/presentation/saml_authentication/widgets/saml_authentication_content_test.dart <==
import 'package:bloc_test/bloc_test.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mocktail/mocktail.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_platform_authentication_ui/src/core/authentication/presentation/bloc/authentication_bloc.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/l10n_extension.dart';
import 'package:senior_platform_authentication_ui/src/core/widgets/base_authentication_screen.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/cubit/saml_authentication_cubit.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_content.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_error.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_loading.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_onboarding.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_webview.dart';

import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';

import '../../../../mocks/webview/webview_platform_mock.dart';

class MockAuthenticationBloc
    extends MockBloc<AuthenticationEvent, AuthenticationState>
    implements AuthenticationBloc {}

class MockSAMLAuthenticationCubit extends MockCubit<SAMLAuthenticationState>
    implements SAMLAuthenticationCubit {}

void main() {
  late AuthenticationBloc authenticationBloc;
  late SAMLAuthenticationCubit samlAuthenticationCubit;

  setUp(() {
    authenticationBloc = MockAuthenticationBloc();
    samlAuthenticationCubit = MockSAMLAuthenticationCubit();
    WebViewPlatform.instance = WebViewPlatformMock();
  });

  Widget makeTestableWidget() {
    return SeniorDesignSystem(
      child: MultiBlocProvider(
        providers: [
          BlocProvider<AuthenticationBloc>(
            create: (BuildContext context) => authenticationBloc,
          ),
          BlocProvider<SAMLAuthenticationCubit>(
            create: (BuildContext context) => samlAuthenticationCubit,
          ),
        ],
        child: BaseAuthenticationScreen(
          child: SeniorBackdrop(
            title: Builder(
                builder: (context) => Text(context.l10n.saml_screen_title)),
            body: const SAMLAuthenticationContent(
              username: 'username',
              tenantDomain: 'tenantDomain',
            ),
          ),
        ),
      ),
    );
  }

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.onboarding',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial());

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final onboardingFinder = find.byType(SAMLAuthenticationOnboarding);

    expect(blocBuilderFinder, findsOneWidget);
    expect(onboardingFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.loading',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.loading,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final loadingFinder = find.byType(SAMLAuthenticationLoading);

    expect(blocBuilderFinder, findsOneWidget);
    expect(loadingFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.error',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.error,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final errorFinder = find.byType(SAMLAuthenticationError);

    expect(blocBuilderFinder, findsOneWidget);
    expect(errorFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.webview',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.webview,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final webviewFinder = find.byType(SAMLAuthenticationWebview);

    expect(blocBuilderFinder, findsOneWidget);
    expect(webviewFinder, findsOneWidget);
  });
}

==> senior_platform_authentication_ui-4.0.0.tar.gz: test/src/presentation/saml_authentication/widgets/saml_authentication_content_test.dart <==
import 'package:bloc_test/bloc_test.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mocktail/mocktail.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_platform_authentication_ui/src/core/authentication/presentation/bloc/authentication_bloc.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/l10n_extension.dart';
import 'package:senior_platform_authentication_ui/src/core/widgets/base_authentication_screen.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/cubit/saml_authentication_cubit.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_content.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_error.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_loading.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_onboarding.dart';
import 'package:senior_platform_authentication_ui/src/presentation/saml_authentication/widgets/saml_authentication_webview.dart';
import 'package:webview_flutter_platform_interface/webview_flutter_platform_interface.dart';

import '../../../../mocks/webview/webview_platform_mock.dart';

class MockAuthenticationBloc
    extends MockBloc<AuthenticationEvent, AuthenticationState>
    implements AuthenticationBloc {}

class MockSAMLAuthenticationCubit extends MockCubit<SAMLAuthenticationState>
    implements SAMLAuthenticationCubit {}

void main() {
  late AuthenticationBloc authenticationBloc;
  late SAMLAuthenticationCubit samlAuthenticationCubit;

  setUp(() {
    authenticationBloc = MockAuthenticationBloc();
    samlAuthenticationCubit = MockSAMLAuthenticationCubit();
    WebViewPlatform.instance = WebViewPlatformMock();
  });

  Widget makeTestableWidget() {
    return SeniorDesignSystem(
      child: MultiBlocProvider(
        providers: [
          BlocProvider<AuthenticationBloc>(
            create: (BuildContext context) => authenticationBloc,
          ),
          BlocProvider<SAMLAuthenticationCubit>(
            create: (BuildContext context) => samlAuthenticationCubit,
          ),
        ],
        child: BaseAuthenticationScreen(
          child: SeniorBackdrop(
            title: Builder(
                builder: (context) => Text(context.l10n.samlScreenTitle)),
            body: const SAMLAuthenticationContent(
              username: 'username',
              tenantDomain: 'tenantDomain',
            ),
          ),
        ),
      ),
    );
  }

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.onboarding',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial());

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final onboardingFinder = find.byType(SAMLAuthenticationOnboarding);

    expect(blocBuilderFinder, findsOneWidget);
    expect(onboardingFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.loading',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.loading,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final loadingFinder = find.byType(SAMLAuthenticationLoading);

    expect(blocBuilderFinder, findsOneWidget);
    expect(loadingFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.error',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.error,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final errorFinder = find.byType(SAMLAuthenticationError);

    expect(blocBuilderFinder, findsOneWidget);
    expect(errorFinder, findsOneWidget);
  });

  testWidgets(
      'should render correctly when state.status is SAMLAuthenticationScreenStatus.webview',
      (tester) async {
    when(() => authenticationBloc.state)
        .thenReturn(const AuthenticationState.unknown());

    when(() => samlAuthenticationCubit.state)
        .thenReturn(SAMLAuthenticationState.initial().copyWith(
      status: SAMLAuthenticationScreenStatus.webview,
    ));

    await tester.pumpWidget(makeTestableWidget());

    final blocBuilderFinder = find
        .byType(BlocBuilder<SAMLAuthenticationCubit, SAMLAuthenticationState>);
    final webviewFinder = find.byType(SAMLAuthenticationWebview);

    expect(blocBuilderFinder, findsOneWidget);
    expect(webviewFinder, findsOneWidget);
  });
}
